<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use Illuminate\Http\Request;

class CitiesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create($id)
    {
        $country = City::find($id);
        return view('admin.cities.create', compact('country'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',
            'parent_id' => 'required|exists:cities,id'
        ]);
        $city = new City();
        $city['name->ar'] = $request['name_ar'];
        $city['name->en'] = $request['name_en'];
        $city['parent_id'] = $request['parent_id'];
        $city['type'] = 'city';
        $city->save();
        return redirect()->route('countries.show', $city->parent_id)->with('message', 'تم الإنشاء بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $city = City::find($id);
        $rows = City::where('parent_id', $id)->orderByDesc('id')->get();
        return view('admin.cities.show', compact('rows', 'city'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = City::find($id);
        return view('admin.cities.edit', compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name_ar' => 'required',
            'name_en' => 'required',

        ]);
        $city = City::find($id);
        $city['name->ar'] = $request['name_ar'];
        $city['name->en'] = $request['name_en'];
        $city->update();
        return redirect()->route('countries.show', $city->parent_id)->with('message', 'تم التعديل بنجاح');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
