<?php

namespace App\Http\Resources;

use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;
use JWTAuth;
use Tymon\JWTAuth\Exceptions\JWTException;

class MessagesResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $auth = $request->header('Authentication');
        if ($auth) {
            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return response()->json(['value' => false, 'msg' => \Lang::get('data.wrong_token'), 'code' => 401]);
            }
        }
        return [
            'sender_id' => $this->sender_id,
            'sender_name' => $this->sender->name,
            'sender_image' => $this->sender->image ? asset('images/users/') . $this->sender->image : '',
            'receiver_id' => $this->receiver_id,
            'receiver_name' => $this->receiver->name,
            'receiver_image' => $this->receiver->image ? asset('images/users/') . $this->receiver->image : '',
            'room_id' => $this->room_id,
            'body' => $this->body,
            'type' => $auth ? $user->id == $this->sender_id ? 'sender' : 'receiver' : '',
            'ago' => Carbon::parse($this->created_at)->diffForHumans()
        ];
    }
}
